@@ -14,7 +14,7 @@ from .tele_upload import upload_handel
 from .rclone_upload import rclone_driver
 from .zip7_utils import add_to_zip, extract_archive
 from ..core.getVars import get_val
-from ..core.status.status import ARTask
+from ..core.status.status import ARTask, QBTask
 from ..core.status.upload import TGUploadTask
 from ..functions.Human_Format import human_readable_bytes
 from .dl_generator import generate_directs
@@ -316,7 +316,7 @@ async def check_link(msg,rclone=False,is_zip=False, extract=False, prev_msg=None
                         torlog.exception("exception in direct links.")
 
                     await ul_task.set_inactive()
-                    await print_files(omess,rdict,dl_task.hash, path = dl_path, size=ul_size)
+                    await print_files(omess,rdict, path = path, size=ul_size)
                     torlog.info("here are the files to be uploaded {}".format(rdict))
                 else:
                     res = await rclone_driver(path,rmsg, omess, dl_task)
